|  | Name | Description | Operating Status | Provisioning Status | IP Address | Listeners | Actions
--- | --- | --- | --- | --- | --- | --- | --- | ---
|  | {$ ::(item.name || item.id) $} | {$ ::item.description | noValue $} | {$ ::item.operating_status | decode:table.operatingStatus $} | {$ ::item.provisioning_status | decode:table.provisioningStatus $} | {$ ::item.vip_address $} | {$ item.listeners.length $} |
IP Address {$ ::item.vip_address $} Listeners {$ item.listeners.length $} Provider {$ ::item.provider $} Floating IP Address {$ item.floating_ip.ip || 'None' | translate $} Admin State Up {$ ::item.admin_state_up | yesno $} ID {$ ::item.id $} Subnet ID {$ ::item.vip_subnet_id $} Port ID {$ ::item.vip_port_id $}